==> kubernetes-model-autoscaling-5.1.2-sources.jar: io/fabric8/kubernetes/api/model/autoscaling/v2beta2/ContainerResourceMetricSourceFluentImpl.java <==
package io.fabric8.kubernetes.api.model.autoscaling.v2beta2;

import com.fasterxml.jackson.annotation.JsonProperty;
import java.lang.StringBuilder;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.lang.StringBuffer;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.Boolean;

public class ContainerResourceMetricSourceFluentImpl<A extends io.fabric8.kubernetes.api.model.autoscaling.v2beta2.ContainerResourceMetricSourceFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements io.fabric8.kubernetes.api.model.autoscaling.v2beta2.ContainerResourceMetricSourceFluent<A> {

    private String container;
    private String name;
    private MetricTargetBuilder target;

    public ContainerResourceMetricSourceFluentImpl() {
    }

    public ContainerResourceMetricSourceFluentImpl(io.fabric8.kubernetes.api.model.autoscaling.v2beta2.ContainerResourceMetricSource instance) {
        this.withContainer(instance.getContainer()); 
        this.withName(instance.getName()); 
        this.withTarget(instance.getTarget()); 
    }

    public String getContainer() {
        return this.container;
    }

    public A withContainer(String container) {
        this.container=container; return (A) this;
    }

    public Boolean hasContainer() {
        return this.container != null;
    }

    public A withNewContainer(String arg1) {
        return (A)withContainer(new String(arg1));
    }

    public A withNewContainer(StringBuilder arg1) {
        return (A)withContainer(new String(arg1));
    }

    public A withNewContainer(StringBuffer arg1) {
        return (A)withContainer(new String(arg1));
    }

    public String getName() {
        return this.name;
    }

    public A withName(String name) {
        this.name=name; return (A) this;
    }

    public Boolean hasName() {
        return this.name != null;
    }

    public A withNewName(String arg1) {
        return (A)withName(new String(arg1));
    }

    public A withNewName(StringBuilder arg1) {
        return (A)withName(new String(arg1));
    }

    public A withNewName(StringBuffer arg1) {
        return (A)withName(new String(arg1));
    }

    
/**
 * This method has been deprecated, please use method buildTarget instead.
 * @return The buildable object.
 */
@Deprecated public MetricTarget getTarget() {
        return this.target!=null?this.target.build():null;
    }

    public MetricTarget buildTarget() {
        return this.target!=null?this.target.build():null;
    }

    public A withTarget(MetricTarget target) {
        _visitables.get("target").remove(this.target);
        if (target!=null){ this.target= new MetricTargetBuilder(target); _visitables.get("target").add(this.target);} return (A) this;
    }

    public Boolean hasTarget() {
        return this.target != null;
    }

    public ContainerResourceMetricSourceFluent.TargetNested<A> withNewTarget() {
        return new TargetNestedImpl();
    }

    public ContainerResourceMetricSourceFluent.TargetNested<A> withNewTargetLike(MetricTarget item) {
        return new TargetNestedImpl(item);
    }

    public ContainerResourceMetricSourceFluent.TargetNested<A> editTarget() {
        return withNewTargetLike(getTarget());
    }

    public ContainerResourceMetricSourceFluent.TargetNested<A> editOrNewTarget() {
        return withNewTargetLike(getTarget() != null ? getTarget(): new MetricTargetBuilder().build());
    }

    public ContainerResourceMetricSourceFluent.TargetNested<A> editOrNewTargetLike(MetricTarget item) {
        return withNewTargetLike(getTarget() != null ? getTarget(): item);
    }

    public boolean equals(Object o) {
        if (this == o) return true;
        if (o == null || getClass() != o.getClass()) return false;
        ContainerResourceMetricSourceFluentImpl that = (ContainerResourceMetricSourceFluentImpl) o;
        if (container != null ? !container.equals(that.container) :that.container != null) return false;
        if (name != null ? !name.equals(that.name) :that.name != null) return false;
        if (target != null ? !target.equals(that.target) :that.target != null) return false;
        return true;
    }

    public int hashCode() {
        return java.util.Objects.hash(container,  name,  target,  super.hashCode());
    }

    public class TargetNestedImpl<N> extends MetricTargetFluentImpl<ContainerResourceMetricSourceFluent.TargetNested<N>> implements ContainerResourceMetricSourceFluent.TargetNested<N>,io.fabric8.kubernetes.api.builder.Nested<N> {
        private final MetricTargetBuilder builder;

            TargetNestedImpl(MetricTarget item) {
                this.builder = new MetricTargetBuilder(this, item);
                        
            }

            TargetNestedImpl() {
                this.builder = new MetricTargetBuilder(this);
                        
            }

            public N and() {
                return (N) ContainerResourceMetricSourceFluentImpl.this.withTarget(builder.build());
            }

            public N endTarget() {
                return and();
            }
    }


}

==> kubernetes-model-autoscaling-5.3.0-sources.jar: io/fabric8/kubernetes/api/model/autoscaling/v2beta2/ContainerResourceMetricSourceFluentImpl.java <==
package io.fabric8.kubernetes.api.model.autoscaling.v2beta2;

import com.fasterxml.jackson.annotation.JsonProperty;
import java.lang.StringBuilder;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.lang.StringBuffer;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.Boolean;

public class ContainerResourceMetricSourceFluentImpl<A extends io.fabric8.kubernetes.api.model.autoscaling.v2beta2.ContainerResourceMetricSourceFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements io.fabric8.kubernetes.api.model.autoscaling.v2beta2.ContainerResourceMetricSourceFluent<A> {

    private String container;
    private String name;
    private MetricTargetBuilder target;

    public ContainerResourceMetricSourceFluentImpl() {
    }

    public ContainerResourceMetricSourceFluentImpl(io.fabric8.kubernetes.api.model.autoscaling.v2beta2.ContainerResourceMetricSource instance) {
        this.withContainer(instance.getContainer()); 
        this.withName(instance.getName()); 
        this.withTarget(instance.getTarget()); 
    }

    public String getContainer() {
        return this.container;
    }

    public A withContainer(String container) {
        this.container=container; return (A) this;
    }

    public Boolean hasContainer() {
        return this.container != null;
    }

    public A withNewContainer(StringBuilder arg1) {
        return (A)withContainer(new String(arg1));
    }

    public A withNewContainer(int[] arg1,int arg2,int arg3) {
        return (A)withContainer(new String(arg1, arg2, arg3));
    }

    public A withNewContainer(char[] arg1) {
        return (A)withContainer(new String(arg1));
    }

    public A withNewContainer(StringBuffer arg1) {
        return (A)withContainer(new String(arg1));
    }

    public A withNewContainer(byte[] arg1,int arg2) {
        return (A)withContainer(new String(arg1, arg2));
    }

    public A withNewContainer(byte[] arg1) {
        return (A)withContainer(new String(arg1));
    }

    public A withNewContainer(char[] arg1,int arg2,int arg3) {
        return (A)withContainer(new String(arg1, arg2, arg3));
    }

    public A withNewContainer(byte[] arg1,int arg2,int arg3) {
        return (A)withContainer(new String(arg1, arg2, arg3));
    }

    public A withNewContainer(byte[] arg1,int arg2,int arg3,int arg4) {
        return (A)withContainer(new String(arg1, arg2, arg3, arg4));
    }

    public A withNewContainer(String arg1) {
        return (A)withContainer(new String(arg1));
    }

    public String getName() {
        return this.name;
    }

    public A withName(String name) {
        this.name=name; return (A) this;
    }

    public Boolean hasName() {
        return this.name != null;
    }

    public A withNewName(StringBuilder arg1) {
        return (A)withName(new String(arg1));
    }

    public A withNewName(int[] arg1,int arg2,int arg3) {
        return (A)withName(new String(arg1, arg2, arg3));
    }

    public A withNewName(char[] arg1) {
        return (A)withName(new String(arg1));
    }

    public A withNewName(StringBuffer arg1) {
        return (A)withName(new String(arg1));
    }

    public A withNewName(byte[] arg1,int arg2) {
        return (A)withName(new String(arg1, arg2));
    }

    public A withNewName(byte[] arg1) {
        return (A)withName(new String(arg1));
    }

    public A withNewName(char[] arg1,int arg2,int arg3) {
        return (A)withName(new String(arg1, arg2, arg3));
    }

    public A withNewName(byte[] arg1,int arg2,int arg3) {
        return (A)withName(new String(arg1, arg2, arg3));
    }

    public A withNewName(byte[] arg1,int arg2,int arg3,int arg4) {
        return (A)withName(new String(arg1, arg2, arg3, arg4));
    }

    public A withNewName(String arg1) {
        return (A)withName(new String(arg1));
    }

    
/**
 * This method has been deprecated, please use method buildTarget instead.
 * @return The buildable object.
 */
@Deprecated public MetricTarget getTarget() {
        return this.target!=null?this.target.build():null;
    }

    public MetricTarget buildTarget() {
        return this.target!=null?this.target.build():null;
    }

    public A withTarget(MetricTarget target) {
        _visitables.get("target").remove(this.target);
        if (target!=null){ this.target= new MetricTargetBuilder(target); _visitables.get("target").add(this.target);} return (A) this;
    }

    public Boolean hasTarget() {
        return this.target != null;
    }

    public ContainerResourceMetricSourceFluent.TargetNested<A> withNewTarget() {
        return new TargetNestedImpl();
    }

    public ContainerResourceMetricSourceFluent.TargetNested<A> withNewTargetLike(MetricTarget item) {
        return new TargetNestedImpl(item);
    }

    public ContainerResourceMetricSourceFluent.TargetNested<A> editTarget() {
        return withNewTargetLike(getTarget());
    }

    public ContainerResourceMetricSourceFluent.TargetNested<A> editOrNewTarget() {
        return withNewTargetLike(getTarget() != null ? getTarget(): new MetricTargetBuilder().build());
    }

    public ContainerResourceMetricSourceFluent.TargetNested<A> editOrNewTargetLike(MetricTarget item) {
        return withNewTargetLike(getTarget() != null ? getTarget(): item);
    }

    public boolean equals(Object o) {
        if (this == o) return true;
        if (o == null || getClass() != o.getClass()) return false;
        ContainerResourceMetricSourceFluentImpl that = (ContainerResourceMetricSourceFluentImpl) o;
        if (container != null ? !container.equals(that.container) :that.container != null) return false;
        if (name != null ? !name.equals(that.name) :that.name != null) return false;
        if (target != null ? !target.equals(that.target) :that.target != null) return false;
        return true;
    }

    public int hashCode() {
        return java.util.Objects.hash(container,  name,  target,  super.hashCode());
    }

    public class TargetNestedImpl<N> extends MetricTargetFluentImpl<ContainerResourceMetricSourceFluent.TargetNested<N>> implements ContainerResourceMetricSourceFluent.TargetNested<N>,io.fabric8.kubernetes.api.builder.Nested<N> {
        private final MetricTargetBuilder builder;

            TargetNestedImpl(MetricTarget item) {
                this.builder = new MetricTargetBuilder(this, item);
                        
            }

            TargetNestedImpl() {
                this.builder = new MetricTargetBuilder(this);
                        
            }

            public N and() {
                return (N) ContainerResourceMetricSourceFluentImpl.this.withTarget(builder.build());
            }

            public N endTarget() {
                return and();
            }
    }


}
